from setuptools import setup

setup(name='dsdn_distribution_sc',
      version='0.1',
      description='Distributions',
      packages=['dsdn_distribution_sc'],
      author='Sonali Chawla',
      author_email='sc@gmail.com',
      zip_safe=False)
